@@ -66,6 +66,11 @@ void ScriptBinder::down(void)
 {
 }
 
+bool ScriptBinder::select(ScriptInterp *interp)
+{
+	return false;
+}
+
 bool ScriptBinder::control(ScriptImage *img, char **args)
 {
 	return false;
@@ -92,8 +97,14 @@ bool ScriptBinder::rebuild(ScriptCompiler *img)
 
 void ScriptBinder::shutdown(void)
 {
+	static bool flag = false;
+
 	ScriptBinder *node = ScriptBinder::first;
 
+	if(flag)
+		return;
+
+	flag = true;
 	while(node)
 	{
 		node->down();
