@@ -43,21 +43,9 @@ using namespace ost;
 ScriptCompiler::ScriptCompiler(ScriptCommand *cmd, const char *symset) :
 ScriptImage(cmd, symset)
 {
-        static Script::Initial initial[] = {
-                {"script.index", 6 * SCRIPT_STACK_SIZE, ""},
-                {"script.stack", 3, "-"},
-                {"script.error", 64, "none"},
-                {"script.home", 64, "none"}, 
-                {"script.token", 1, ","},    
-                {"script.decimal", 1, "."},  
-                {NULL, 0, NULL}
-        };
-
         inccount = 0;
 	mlist = NULL;
         scrStream = (istream *)&scrSource;
-
-        load(initial);
 }
 
 void ScriptCompiler::fastBranch(ScriptInterp *interp)
@@ -514,19 +502,23 @@ int ScriptCompiler::compileDefinitions(const char *filename)
 	if(!cp || stricmp(cp, ".def"))
 		return 0;
 
-	cp = strrchr(cp, '/');
+	cp = strrchr(filename, '/');
 #ifdef	WIN32
 	if(!cp)
-		cp = strrchr(cp, '\\');
+		cp = strrchr(filename, '\\');
 	if(!cp)
-		cp = strchr(cp, ':');
+		cp = strchr(filename, ':');
 #endif
 
 	if(!cp)
 	{
-		snprintf(buffer, sizeof(buffer), "%s/%s",
-			cmds->getLast("include"), filename);
-		filename = buffer;
+		cp = cmds->getLast("include");
+		if(cp)
+		{
+			snprintf(buffer, sizeof(buffer), "%s/%s",
+				cp, filename);
+			filename = buffer;
+		}
 	}
 
 	if(!isFile(filename) || !canAccess(filename))
@@ -572,7 +564,7 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	char *args[SCRIPT_MAX_ARGS + 1];
 	int maxargs = SCRIPT_MAX_ARGS;
 	const char *err;
-	char *cp = strrchr(scrname, '.');
+	char *cp = (char *)strrchr(scrname, '.');
 //	const char *var = cmds->getLast("datafiles");
 	bool trapflag;
 	int argc, key, tlen, initkey = 0, initcount = 0;
@@ -662,12 +654,12 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	gvarlen = strlen(gvarname);
 
 #ifdef	WIN32
-	char *l1 = strrchr(scrname, '/');
-	char *l2 = strrchr(scrname, '\\');
+	const char *l1 = strrchr(scrname, '/');
+	const char *l2 = strrchr(scrname, '\\');
 	if(l1 > l2)
-		cp = l1;
+		cp = (char *)l1;
 	else
-		cp = l2;
+		cp = (char *)l2;
 #else
 	cp = (char *)strrchr(scrname, '/');
 #endif
@@ -1054,6 +1046,17 @@ noexec:
 			continue;
 		}
 
+		if(!stricmp(token, "disuse") && defs)
+		{
+			if(NULL != (token = getToken()))
+			{
+				snprintf(temp, sizeof(temp), "use.%s", token);
+				cmds->setValue(temp, "none");
+				continue;
+			}
+			token = "disuse";
+		}
+
 		if(!stricmp(token, "use"))
 		{
 			if(NULL != (token = getToken()))
@@ -1063,6 +1066,9 @@ noexec:
 				if(cp)
 					token = cp;
 
+				if(!stricmp(token, "none"))
+					continue;
+
 				if(!Script::use(token))
 					slog.warn("%s(%d): %s: package missing", filename, lnum, token);
 			}
