@@ -57,11 +57,25 @@ ScriptThread::~ScriptThread()
 
 void ScriptThread::exit(const char *msg)
 {
-	interp->enter();
+	lock();
 	exiting = true;
 	interp->exitThread(msg);
-	interp->leave();
-	sync();
+	release();
+	Thread::sync();
+}
+
+void ScriptThread::exitEvent(const char *evt, bool flag)
+{
+	bool rtn;
+	lock();
+	rtn = interp->eventThread(evt, flag);
+	if(rtn)
+		interp->exitThread(NULL);
+	release();
+	if(rtn)
+		Thread::sync();
+	else
+		Thread::yield();
 }
 
 timeout_t ScriptThread::getTimeout(void)
@@ -69,3 +83,27 @@ timeout_t ScriptThread::getTimeout(void)
 	return 3600000l;
 }
 
+void ScriptThread::block(void)
+{
+	setCancel(cancelDisabled);
+}
+
+void ScriptThread::unblock(void)
+{
+	setCancel(cancelDeferred);
+	Thread::yield();
+}
+
+void ScriptThread::lock(void)
+{
+	block();
+	interp->enter();
+}
+
+void ScriptThread::release(void)
+{
+	interp->release();
+	interp->leave();
+	unblock();
+}
+
